import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'dashboard' }
    }]
  },
  {
    path: '/live',
    component: Layout,
    meta: {
      roles: ['admin', 'editor']
    },
    children: [
      {
        path: 'list',
        name: 'live',
        component: () => import('@/views/live/list'),
        meta: { title: '日志列表', icon: 'el-icon-s-help' }
      },
      {
        path: 'edit/:id(\\d+)',
        component: () => import('@/views/live/edit'),
        name: 'EditBanner',
        meta: { title: '查看日志参数', noCache: true, activeMenu: '/live/list' },
        hidden: true
      }
    ]
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

export const asyncRoutes = [
  {
    path: '/home',
    component: Layout,
    meta: {
      title: '图片列表',
      icon: 'el-icon-setting',
      roles: ['admin']
    },
    children: [
      {
        path: 'list',
        name: 'home',
        component: () => import('@/views/home/list'),
        meta: { title: '图片列表', icon: 'el-icon-s-help', roles: ['admin'] }
      },
      {
        path: 'edit/:id(\\d+)',
        name: 'edithome',
        component: () => import('@/views/home/edit'),
        meta: { title: '查看图片', icon: 'el-icon-s-help', roles: ['admin'] },
        hidden: true
      },
      {
        path: 'create',
        name: 'createHome',
        component: () => import('@/views/home/create'),
        meta: { title: '创建图片', icon: 'el-icon-s-help', roles: ['admin'] }
      }
    ]
  },
  {
    path: '/setting',
    component: Layout,
    name: 'setting',
    meta: {
      title: '基本设置',
      icon: 'el-icon-setting',
      roles: ['admin']
    },
    children: [
      {
        path: 'edit',
        component: () => import('@/views/setting/edit'),
        name: 'CreateBanner',
        meta: { title: '参数设置', icon: 'el-icon-edit' }
      }
    ]
  },
  {
    path: '/brand',
    component: Layout,
    name: 'brand',
    meta: {
      title: '基本设置',
      icon: 'el-icon-setting',
      roles: ['admin']
    },
    children: [
      {
        path: 'edit',
        component: () => import('@/views/brand/edit'),
        name: 'CreateBanner',
        meta: { title: '品牌介绍', icon: 'el-icon-edit' }
      }
    ]
  },
  {
    path: '/banner',
    component: Layout,
    redirect: '/banner/list',
    name: 'banner',
    meta: {
      title: '轮播设置',
      icon: 'el-icon-s-help',
      roles: ['admin']
    },
    children: [
      {
        path: 'create',
        component: () => import('@/views/banner/create'),
        name: 'CreateBanner',
        meta: { title: '创建轮播图', icon: 'el-icon-edit' }
      },
      {
        path: 'edit/:id(\\d+)',
        component: () => import('@/views/banner/edit'),
        name: 'EditBanner',
        meta: { title: '修改轮播图', noCache: true, activeMenu: '/banner/list' },
        hidden: true
      },
      {
        path: 'list',
        component: () => import('@/views/banner/list'),
        name: 'BannerList',
        meta: { title: '轮播图列表', icon: 'el-icon-s-order' }
      }
    ]
  },
  {
    path: '/city',
    component: Layout,
    meta: {
      roles: ['admin']
    },
    children: [
      {
        path: 'list',
        name: 'city',
        component: () => import('@/views/city/list'),
        meta: { title: '开放区域列表', icon: 'el-icon-s-help' }
      }
    ]
  },
  {
    path: '/join',
    component: Layout,
    meta: {
      roles: ['admin']
    },
    children: [
      {
        path: 'list',
        name: 'join',
        component: () => import('@/views/join/list'),
        meta: { title: '管理员列表', icon: 'el-icon-s-help' }
      }
    ]
  }
]

const createRouter = () => new Router({
  // mode: 'hash', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
